cloud_inquisitor\.plugins\.notifiers\.email
-------------------------------------------

.. automodule:: cloud_inquisitor.plugins.notifiers.email
    :members:
    :no-undoc-members:
    :show-inheritance:
